==> haskell-listlike-4.5.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ListLike
version: 4.5.1
id: ListLike-4.5.1-VOymscQ1P222rHgUc2G0R
key: ListLike-4.5.1-VOymscQ1P222rHgUc2G0R
license: BSD3
copyright: Copyright (c) 2007-2008 John Goerzen
maintainer: John Lato <jwlato@gmail.com>
stability: Stable
homepage: http://github.com/JohnLato/listlike
synopsis: Generic support for list-like structures
description:
    Generic support for list-like structures in Haskell.
    .
    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.
    .
    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.
category: Generics
author: John Goerzen
exposed: True
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.Chars
    Data.ListLike.CharString Data.ListLike.FoldableLL Data.ListLike.IO
    Data.ListLike.Instances Data.ListLike.String Data.ListLike.Text
    Data.ListLike.Text.Builder Data.ListLike.Text.Text
    Data.ListLike.Text.TextLazy Data.ListLike.UTF8 Data.ListLike.Utils
    Data.ListLike.Vector Data.ListLike.Vector.Generic
    Data.ListLike.Vector.Storable Data.ListLike.Vector.Unboxed
    Data.ListLike.Vector.Vector Data.ListLike.DList
    Data.ListLike.FMList
abi: 2ac701078e3e04a0803d8a9434e5fbc3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/ListLike-4.5.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/ListLike-4.5.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/ListLike-4.5.1
hs-libraries: HSListLike-4.5.1-VOymscQ1P222rHgUc2G0R
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    deepseq-1.4.2.0 dlist-0.8.0.2-GWAMmbX9rLg3tqrbOizHGv
    fmlist-0.9-HSpOxlAQ61BEyR9pTkrEdW
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html: /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-listlike-4.5.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ListLike
version: 4.5.1
id: ListLike-4.5.1-FD7E38UOmVbIIugBih4smQ
key: ListLike-4.5.1-FD7E38UOmVbIIugBih4smQ
license: BSD3
copyright: Copyright (c) 2007-2008 John Goerzen
maintainer: John Lato <jwlato@gmail.com>
stability: Stable
homepage: http://github.com/JohnLato/listlike
synopsis: Generic support for list-like structures
description:
    Generic support for list-like structures in Haskell.
    .
    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.
    .
    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.
category: Generics
author: John Goerzen
exposed: True
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.Chars
    Data.ListLike.CharString Data.ListLike.FoldableLL Data.ListLike.IO
    Data.ListLike.Instances Data.ListLike.String Data.ListLike.Text
    Data.ListLike.Text.Builder Data.ListLike.Text.Text
    Data.ListLike.Text.TextLazy Data.ListLike.UTF8 Data.ListLike.Utils
    Data.ListLike.Vector Data.ListLike.Vector.Generic
    Data.ListLike.Vector.Storable Data.ListLike.Vector.Unboxed
    Data.ListLike.Vector.Vector Data.ListLike.DList
    Data.ListLike.FMList
abi: e9a04e8af964e7d3adc7ce057ff11ad9
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/ListLike-4.5.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/ListLike-4.5.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/ListLike-4.5.1
hs-libraries: HSListLike-4.5.1-FD7E38UOmVbIIugBih4smQ
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    deepseq-1.4.2.0 dlist-0.8.0.2-GWAMmbX9rLg3tqrbOizHGv
    fmlist-0.9-HSpOxlAQ61BEyR9pTkrEdW
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html: /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
